parse

Function parse 

pub fn parse(source: &str) -> Result<FSharpRoot, OakError>
Parses F# source code into a FSharpRoot AST.

This is a convenience function that initializes the language, builder, and parser to process the source text.

Errors

Returns an oak_core::OakError if parsing fails.